"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assignmentconfig import AssignmentConfig, AssignmentConfigTypedDict
from mixpeek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TaxonomyExtractionConfigTypedDict(TypedDict):
    r"""Configuration for taxonomy-based entity extraction during ingestion"""

    taxonomy: str
    r"""Taxonomy name or ID to use for classification"""
    assignment: NotRequired[AssignmentConfigTypedDict]
    r"""Configuration for how classifications should be assigned to features"""


class TaxonomyExtractionConfig(BaseModel):
    r"""Configuration for taxonomy-based entity extraction during ingestion"""

    taxonomy: str
    r"""Taxonomy name or ID to use for classification"""

    assignment: Optional[AssignmentConfig] = None
    r"""Configuration for how classifications should be assigned to features"""
